#!/bin/sh
# This script should be called from connector_manager.sh, and accepts the following parameters:
#  start_myconnector.sh <CONNECTORNAME> <SERVERNAME> <OPTIONAL ADDITIONAL PARAMETERS>
#
#  Any line that has the #   <-- Check on it should be reviewed for your connector
#
#The file CWSharedEnv.sh defines the following in it's classpath, so there is no need to override any of these:
#Please go look at this file, on the solaris build, it is in the $CROSSWORLDS/setup directory.
#All of these are bundeled together into the CLASSPATH variable which is then exported for your use
#It defines things such as:
#CORECW
#RSA 
#CWUTILS 
#XML_PARSER 
#DATAHANDLERS 
#MQ 
#ORB1 
#ORB2 
#JVM_FLAGS 
#JRT 
#JAVA_SECURITY 
#WEBLOGIC 
#
################################################
# General connector variable initialization section
# No changes should be necessary
# set CONNECTOR_TYPE  -- This is needed to differentate Java from C++ conncetors 
# set CONDIR  the directory where the specific connector resides, then change to this directory
# set CONNAME the name to be the application connector that is starting
# set SERVER  the server name to be the interchange that is being targeted
# set CONJAR to the fullpath of the connector .jar file.

CONNAME=$1
SERVER=$2

# Set any connector specific Variables here
#CON_SPEC_JAR_ONE=${CONDIR}/abc.jar                                               #   <-- Check
#CON_SPEC_JAR_TWO=${CONDIR}/def.jar                                               #   <-- Check

# Set a variable for driver class and the licensing information
JDBCDRIVERPATH=

# Set Conn specific classpath here 
#Any specific variables defined above need to be added to the CON_SPECIFIC_CLASSPATH below.
UTILS=${CROSSWORLDS}/lib/xwutil.jar:${CROSSWORLDS}/lib/spy/lib/spy.jar
CON_SPECIFIC_CLASSPATH=:${JDBCDRIVERPATH}:${UTILS}:${CON_SPEC_JAR_ONE}:${CON_SPEC_JAR_TWO}


if [ -f $CROSSWORLDS/wbiart/wbiart.jar ]
then
# Using the new run-time code split
. ${CROSSWORLDS}/bin/CWConnEnv.sh

echo $CWCLASSES
CONDIR=${CROSSWORLDS}/connectors/${CONNAME}

# Going to the directory where the connector class files reside
cd /
cd "${CONDIR}"

# Define all the connector specific variables here
CONNECTOR_TYPE="-l"
CONNECTOR_AGENT=com.crossworlds.connectors.JDBC.JDBCConnectorAgent
CONJAR=${CONDIR}/CW${CONNAME}.jar
LOCAL_JVM_FLAGS=${CONN_JAVA_JVM_FLAGS}

#Check for BIA_ Connector JAR
if test -f ${CONDIR}/BIA_${CONNAME}.jar 
then
CONJAR=${CONDIR}/BIA_${CONNAME}.jar 
fi

# Set any Connector specific start options here (Like -t or -fno etc.)
CON_START_OPTIONS=" "
# All the variables that need to be passed to the callee need to be defined here
JCLASSES=.:${CONJAR}:${UTILS}:${JDBCDRIVERPATH}:${JCLASSES}:${CWCLASSES}:${CON_SPEC_JAR_ONE}:${CON_SPEC_JAR_TWO}
export JCLASSES
# Call the base start_adapter.sh to start the connector
exec start_adapter.sh ${CONNECTOR_TYPE}${CONNECTOR_AGENT} -n${CONNAME}Connector -s${SERVER} ${CON_START_OPTIONS} $3 $4

else

. ${CROSSWORLDS}/bin/CWConnEnv.sh
echo $CWCLASSES
CONDIR=${CROSSWORLDS}/connectors/${CONNAME}
if [ "${OS}" = "SUNOS" ]
then
LD_LIBRARY_PATH=${CONDIR}:${LD_LIBRARY_PATH}:/usr/java131/jre/bin
export LD_LIBRARY_PATH
elif [ "${OS}" = "HP-UX" ]
then
SHLIB_PATH=${CONDIR}:${SHLIB_PATH}
export SHLIB_PATH
else
LIBPATH=${CONDIR}:${LIBPATH}
export LIBPATH
fi


################################################
# Connector specific variable initialization section
# Set your Connector agent here 

#The following two sections tell the script what language the connector was written in,
# and help it make the correct calls. 
#Please enable one of the next sections

#For C++ connectors enable the following
#CONNECTOR_TYPE="-d"                                                             #   <-- Check
#CONNECTOR_AGENT=${CONNAME}                                                      #   <-- Check
#CONJAR=""
#LOCAL_JVM_FLAGS=${CONN_CPP_JVM_FLAGS}

#For Java connectors enable the following
CONNECTOR_TYPE="-l"                                                                     #   <-- Check
CONNECTOR_AGENT=com.crossworlds.connectors.JDBC.JDBCConnectorAgent    #   <-- Check
CONJAR=${CONDIR}/CW${CONNAME}.jar
LOCAL_JVM_FLAGS=${CONN_JAVA_JVM_FLAGS}

#Check for BIA_ Connector JAR
if test -f ${CONDIR}/BIA_${CONNAME}.jar 
then
CONJAR=${CONDIR}/BIA_${CONNAME}.jar 
fi


# Set any Connector specific start options here (Like -t or -fno etc.)
CON_START_OPTIONS=" "                                                            #   <-- Check


# We are using the JVM_FLAGS that are set in the CWSharedEnv.sh file, if you need to use different flags,
#  Change $JVM_FLAGS to be what you need to use.
# No changes should be necessary below this line.

CWCLASSES=${UTILS}:${CWCLASSES}
CLASSPATH=${CONJAR}:${CWCLASSES}:${CON_SPECIFIC_CLASSPATH}
echo $CLASSPATH
${CROSSWORLDS}/bin/check_path.sh "$CLASSPATH"
if [ "${OS}" = "SUNOS" ]
then
exec ${CWJAVA} ${LOCAL_JVM_FLAGS} -Xms64m -Djava.library.path=${LD_LIBRARY_PATH} -Djava.ext.dirs=${JRE_EXT_DIRS}  -classpath ${CLASSPATH}  AppEndWrapper ${CONNECTOR_TYPE}${CONNECTOR_AGENT} -n${CONNAME}Connector -s${SERVER} ${CON_START_OPTIONS}  $3 $4 $5 $6 $7 $8 $9
elif [ "${OS}" = "HP-UX" ]
then
exec ${CWJAVA} ${LOCAL_JVM_FLAGS} -Xms64m -Djava.library.path=${SHLIB_PATH} -Djava.ext.dirs=${JRE_EXT_DIRS} -classpath ${CLASSPATH}  AppEndWrapper ${CONNECTOR_TYPE}${CONNECTOR_AGENT} -n${CONNAME}Connector -s${SERVER} ${CON_START_OPTIONS}  $3 $4 $5 $6 $7 $8 $9
else
exec ${CWJAVA} ${LOCAL_JVM_FLAGS} -Xms64m -Djava.library.path=${LIBPATH} -Djava.ext.dirs=${JRE_EXT_DIRS} -classpath ${CLASSPATH}  AppEndWrapper ${CONNECTOR_TYPE}${CONNECTOR_AGENT} -n${CONNAME}Connector -s${SERVER} ${CON_START_OPTIONS}  $3 $4 $5 $6 $7 $8 $9
fi

fi
# run-time split endif
